@@ -11,13 +11,12 @@
 
 from __future__ import absolute_import, division, unicode_literals
 
-from mo_dots.lists import is_many
-
-from mo_future import is_text, is_binary
 import sys
 
-from mo_dots import Data, Null, is_data, listwrap, unwraplist
-from mo_future import PY3, text
+from mo_dots import Data, Null, is_data, listwrap, unwraplist, to_data
+from mo_dots.lists import is_many
+from mo_future import is_text, PY2
+from mo_future import text
 from mo_logs.strings import CR, expand_template, indent
 
 FATAL = "FATAL"
@@ -36,7 +35,7 @@ class LogItem(object):
         self.params = params
 
     def __data__(self):
-        return Data(self.__dict__)
+        return to_data(self.__dict__)
 
 
 class Except(Exception, LogItem):
@@ -133,10 +132,13 @@ class Except(Exception, LogItem):
                 return True
         return False
 
-    def __unicode__(self):
+    def __str__(self):
         output = self.context + ": " + self.template + CR
         if self.params:
-            output = expand_template(output, self.params)
+            try:
+                output = expand_template(output, self.params)
+            except Exception as cause:
+                return self.template
 
         if self.trace:
             output += indent(format_trace(self.trace))
@@ -153,18 +155,14 @@ class Except(Exception, LogItem):
 
         return output
 
-    if PY3:
-
-        def __str__(self):
-            return self.__unicode__()
-
-    else:
+    if PY2:
+        __unicode__ = __str__
 
         def __str__(self):
             return self.__unicode__().encode("latin1", "replace")
 
     def __data__(self):
-        output = Data({k: getattr(self, k) for k in vars(self)})
+        output = to_data({k: getattr(self, k) for k in vars(self)})
         output.cause = unwraplist([c.__data__() for c in listwrap(output.cause)])
         return output
 
